@@ -63,15 +63,19 @@ class dicto(UserDict, dict):  # <- allows passing isinstance(dict, d)
 
     getd = getd
     getf = getf
+    popf = popf
     setz = setz
     setv = setv
     setdz = setdz
     setdv = setdv
     setfz = setfz
     setfv = setfv
+    biset = biset
     has = has
     hasd = hasd
     hasf = hasf
+    delz = delz
+    delsz = delsz
     incv = incv
     incz = incz
     decv = decv
@@ -80,7 +84,6 @@ class dicto(UserDict, dict):  # <- allows passing isinstance(dict, d)
     merge = merge
     flip = flip
     replacekey = replacekey
-    removekeys = removekeys
     take = take
     taked = taked
     takef = takef
