@@ -16,21 +16,24 @@ Naming convention of the functions:
 from typing import Any, Callable, Iterable, Literal, Mapping, MutableMapping, Tuple
 
 from utilicity._types import T, TNumber
-from utilicity.sentinels import _Unset
 
 
 __all__ = (
     'getd',
     'getf',
+    'popf',
     'setz',
     'setv',
     'setdz',
     'setdv',
     'setfz',
     'setfv',
+    'biset',
     'has',
     'hasd',
     'hasf',
+    'delz',
+    'delsz',
     'incv',
     'incz',
     'decv',
@@ -39,7 +42,6 @@ __all__ = (
     'merge',
     'flip',
     'replacekey',
-    'removekeys',
     'take',
     'taked',
     'takef',
@@ -63,8 +65,6 @@ def getd(obj: Mapping, key, default=None):
         >>> getd(d, 'bar', 1)
         1
     """
-    if default is _Unset:
-        return obj[key]
     return obj.get(key, default)
 
 
@@ -84,6 +84,26 @@ def getf(obj: Mapping, key, fallback: Callable[[], Any]):
         return fallback()
 
 
+def popf(obj: MutableMapping, key, fallback: Callable[[], Any]):
+    """Deletes obj[key] and returns the value.
+
+    If key doesn't exist, returns fallback().
+
+    Example:
+        >>> d = {'foo': 1}
+        >>> popf(d, 'foo', lambda: 2)
+        1
+        >>> d
+        {}
+        >>> popf(d, 'foo', fallback=lambda: 1)
+        1
+    """
+    try:
+        return obj.pop(key)
+    except KeyError:
+        return fallback()
+
+
 def setz(obj: MutableMapping, key, value) -> obj:
     """Sets obj[key] to value, returns obj.
 
@@ -178,6 +198,17 @@ def setfv(obj: MutableMapping, key, fallback: Callable[[], Any]):
         return value
 
 
+def biset(obj: MutableMapping, key, value) -> obj:
+    """Sets obj[key] to value and also obj[value] to key, returns obj.
+
+    Example:
+        >>> biset({}, 'foo', 1)
+        {'foo': 1, 1: 'foo'}
+    """
+    obj[key], obj[value] = value, key
+    return obj
+
+
 def has(obj: Mapping, key) -> bool:
     """Checks if obj[key] exists.
 
@@ -227,6 +258,66 @@ def hasf(obj: MutableMapping, key, fallback: Callable[[], Any]) -> bool:
     return False
 
 
+def delz(obj: MutableMapping, key, keyerror: bool = True) -> obj:
+    """Removes the key from the obj, returns the obj. If keyerror is False,
+    missing key is ignored, otherwise KeyError is raised.
+
+    Args:
+        obj: Object to remove keys from.
+        key: Keys to remove.
+        keyerror: If True, raise KeyError if a key is not found.
+                  Default is True.
+
+    Example:
+        >>> d = {'foo': 1}
+        >>> delz(d, 'foo')
+        {}
+        >>> delz(d, 'foo')
+        Traceback (most recent call last):
+        ...
+        KeyError: 'foo'
+        >>> delz(d, 'foo', keyerror=False)
+        {}
+        >>> d
+        {}
+    """
+    try:
+        del obj[key]
+    except KeyError:
+        if keyerror:
+            raise
+    return obj
+
+
+def delsz(obj: MutableMapping,
+          keys: Iterable,
+          keyerror: bool = True
+          ) -> obj:
+    """Removes the keys from the obj, returns the obj. If keyerror is False,
+    missing keys are ignored, otherwise KeyError is raised.
+
+    Args:
+        obj: Object to remove keys from.
+        keys: Keys to remove.
+        keyerror: If True, raise KeyError if a key is not found.
+                  Default is True.
+
+    Example:
+        >>> d = {'foo': 1, 'bar': 2}
+        >>> delsz(d, ['foo'])
+        {'bar': 2}
+        >>> delsz(d, ['baz'])
+        Traceback (most recent call last):
+        ...
+        KeyError: 'baz'
+        >>> delsz(d, ['baz'], keyerror=False)
+        {'bar': 2}
+    """
+    for key in keys:
+        delz(obj, key, keyerror)
+    return obj
+
+
 def incv(obj: MutableMapping[Any, TNumber], key, n: TNumber = 1) -> TNumber:
     """Increments obj[key] by n.
 
@@ -453,39 +544,6 @@ def replacekey(obj: MutableMapping,
     return obj
 
 
-def removekeys(obj: MutableMapping,
-               keys: Iterable,
-               keyerror: bool = True
-               ) -> obj:
-    """Removes the keys from the obj, returns the obj. If keyerror is False,
-    missing keys are ignored, otherwise KeyError is raised.
-
-    Args:
-        obj: Object to remove keys from.
-        keys: Keys to remove.
-        keyerror: If True, raise KeyError if a key is not found.
-                  Default is True.
-
-    Example:
-        >>> d = {'foo': 1, 'bar': 2}
-        >>> removekeys(d, ['foo'])
-        {'bar': 2}
-        >>> removekeys(d, ['baz'])
-        Traceback (most recent call last):
-        ...
-        KeyError: 'baz'
-        >>> removekeys(d, ['baz'], keyerror=False)
-        {'bar': 2}
-    """
-    for key in keys:
-        try:
-            del obj[key]
-        except KeyError:
-            if keyerror:
-                raise
-    return obj
-
-
 def take(obj: MutableMapping,
          keys: Iterable,
          keyerror: bool = True
